#!/usr/bin/python3

import nfc
import binascii
import errno
import contextlib
import ctypes
import threading


class TimeoutException(IOError):
    errno = errno.EINTR

@contextlib.contextmanager
def time_limit_with_thread(timeout_secs):
    thread_id = ctypes.c_ulong(threading.get_ident())
    def raise_exception():
        modified_thread_state_nums :int = ctypes.pythonapi.PyThreadState_SetAsyncExc(thread_id, ctypes.py_object(TimeoutException))
        if modified_thread_state_nums == 0:
            raise ValueError('Invalid thread id. thread_id:{}'.format(thread_id))
        elif modified_thread_state_nums > 1:
            # Normally do not go through this path, but clear unthrown Exceptions just in case
            ctypes.pythonapi.PyThreadState_SetAsyncExc(thread_id, None)
            raise SystemError('PyThreadState_SetAsyncExc failure.')

    timer = threading.Timer(timeout_secs, raise_exception)
    timer.setDaemon(True)
    timer.start()
    try:
        yield
    finally:
        timer.cancel()
        timer.join()

def nfc_reader():
    clf = nfc.ContactlessFrontend('usb')
    print('please touch card:')
    try:
        tag = clf.connect(rdwr={'on-connect': lambda tag: False})
    finally:
        clf.close()
    if tag is False:
        print('Cannot read card')
    else:
        idm = binascii.hexlify(tag.idm)
        print(idm)
        print('please released card')

if __name__=='__main__':
    timeout_secs = 3
    with time_limit_with_thread(timeout_secs):
        try:
            nfc_reader()
        except TimeoutException:
            print('timeout.')