import time
import numpy as np
import cv2 as cv

import busio
import board

import smbus
import adafruit_amg88xx
import random

def thermo() :
    # I2Cバスの初期化
    i2c_thrm_adr = 0x68
    i2c_dis_adr = 0x70
    i2c_bus = busio.I2C(board.SCL, board.SDA)
    i2c = smbus.SMBus(1)
    thermo = adafruit_amg88xx.AMG88XX(i2c_bus, addr = i2c_thrm_adr)

    time.sleep(0.2)

    # カメラ初期化
    cap = cv.VideoCapture(0)

    # 顔の分類器の作成
    faceCascade = cv.CascadeClassifier('haarcascades/haarcascade_frontalface_default.xml')

    n = 0
    result = 0

    while True:
        if n == 10 :
            result = result/n
            break

        else :
            ret, frame = cap.read()
            frame = cv.flip(frame, -1) # Flip vertically
            h, w, c = frame.shape

            # カメラの画像をモノクロにする
            gray = cv.cvtColor(frame, cv.COLOR_BGR2GRAY)

            # 顔の認識
            facerect = faceCascade.detectMultiScale(gray, scaleFactor=1.2, minNeighbors=6, minSize=(1, 1))

            if len(facerect) > 0:
                for rect in facerect:
                    # 配列のスライス→ rect[開始位置:終了位置] rect[0:2]→[左上X座標, 左上Y座標]
                    cv.rectangle(frame, tuple(rect[0:2]), tuple(rect[0:2]+rect[2:4]), (0, 0, 255), thickness=2)

                max_temp = 0.0
                i2c.write_i2c_block_data(0x70,0x00,[0x51])
                time.sleep(0.1)
                block = i2c.read_i2c_block_data(i2c_dis_adr,0x00,6)
                if(block[0]==6):
                    distance = (block[2]<<8 | block[3])
                else:
                    distance = (block[2]<<8 | block[3]) + block[4]
                pixels_array = np.array(thermo.pixels)
                pixels_ave = np.average(pixels_array)
                pixels_max = np.amax(pixels_array[1:6,2:6])   
                pixels_min = np.amin(pixels_array)
                thermistor_temp = i2c.read_word_data(i2c_thrm_adr, 0xE)
                thermistor_temp = thermistor_temp * 0.0625
                offset_thrm = (-0.6857*thermistor_temp+27.187)# 補正式
                if distance <= 60:
                    offset_thrm = offset_thrm-((60-distance)*0.064)# 補正式(対距離)
         
                offset_temp = offset_thrm - 2.0
                max_temp =  round(pixels_max + offset_temp, 1)   #体温を算出

                print('人を検知しました: ')

                print('サーミスタ温度:' + str(thermistor_temp) + ' ℃')
                print('最大温度:' + str(pixels_max) + ' ℃')
                print('オフセット値:' + str(offset_temp) + ' ℃')
                print('体温:' + str(max_temp) + ' ℃')
                print(pixels_array)
                print('対象物までの距離:' + str(distance) + ' cm')
                #rantempe =  random.uniform(35.9, 36.8)
                result = result + max_temp
                #試験用ランダム
                #result = result + rantempe
                n = n + 1

            frame = cv.resize(frame, (1020,765))  # サイズ変更
            cv.imshow('camera capture', frame)
            cv.moveWindow("camera capture", 1025,0) # Window表示位置指定

            k = cv.waitKey(10) & 0xff # Press 'ESC' for exiting video
            if k == 27:
                break

        # 何かキーが押されたかどうかを検出する（検出のため、1ミリ秒待つ）
        #if cv.waitKey(1) > 0:
            #break

    cap.release()
    # 表示したウィンドウを閉じる
    cv.destroyAllWindows()
    return result
